@@ -31,11 +31,15 @@ class InverseLaplaceTransformer(UnilateralInverseTransformer):
     def check(self, expr, s, t, **kwargs):
 
         if expr.has(t):
-            self.error('Expression depends on t')
+            for term in expr.as_ordered_terms():
+                # Allow Subs(Derivativee(undef, t), t, 0)
+                if term.has(t) and not term.is_constant:
+                    self.error('Expression depends on t')
 
     def key(self, expr, s, t, **kwargs):
         return (expr, s, t,
                 kwargs.get('causal', False),
+                kwargs.get('zero_initial_conditions', True),
                 kwargs.get('damped_sin', True),
                 kwargs.get('damping', None))
 
@@ -49,7 +53,6 @@ class InverseLaplaceTransformer(UnilateralInverseTransformer):
         # Convert V(s) to v(t), etc.
         name = expr.func.__name__
         undef = sym.Function(name[0].lower() + name[1:])(t)
-
         result = undef.subs(t, t / scale) / abs(scale)
 
         if shift != 0:
@@ -226,12 +229,27 @@ class InverseLaplaceTransformer(UnilateralInverseTransformer):
                     # Convert s * V(s) to d v(t) / dt
                     result = self.func(factors[1], s, t)
                     result = sym.Derivative(result, t)
+                    if not kwargs.get('zero_initial_conditions', True):
+                        fname = factors[1].func.__name__
+                        func = sym.Function(fname[0].lower() + fname[1:])
+                        result += func(0) * sym.DiracDelta(t)
                     continue
                 elif factors[0].is_Pow and factors[0].args[0] == s and factors[0].args[1] > 0:
                     # Handle higher order differentiation
                     # Convert s ** 2 * V(s) to d^2 v(t) / dt^2
                     result = self.func(factors[1], s, t)
                     result = sym.Derivative(result, t, factors[0].args[1])
+                    if not kwargs.get('zero_initial_conditions', True):
+                        fname = factors[1].func.__name__
+                        func = sym.Function(fname[0].lower() + fname[1:])
+                        v = func(t)
+                        order = factors[0].args[1]
+                        for m in range(order - 1):
+                            result += sym.Derivative(v, t, m).subs(t, 0) * \
+                                sym.DiracDelta(t, order - m - 1)
+                        result += sym.Derivative(v, t, order - 1).subs(t, 0) * \
+                            sym.DiracDelta(t)
+
                     continue
                 elif factors[0].is_Pow and factors[0].args[0] == s and factors[0].args[1] == -1:
                     # Handle integration  1 / s * V(s)
