@@ -1,7 +1,7 @@
 """This module provides the Latex class for formatting
 values and labels.
 
-Copyright 2020--2021 Michael Hayes, UCECE
+Copyright 2020--2022 Michael Hayes, UCECE
 
 """
 
@@ -9,8 +9,10 @@ import re
 from .config import subscripts, greek_letter_names
 
 sub_super_pattern = re.compile(r"([_\^]){([a-zA-Z]+)([0-9]*)}")
-greek_letter_name_pattern = re.compile(r"(.?)(%s)" % '|'.join(greek_letter_names))
-math_symbols_pattern = re.compile('|'.join(['_',  r'\^', r'\\left', r'\\math', r'\\frac', r'\\sqrt']))
+greek_letter_name_pattern = re.compile(
+    r"([^a-zA-Z\\]|^)(%s)([^a-zA-Z]|$)" % '|'.join(greek_letter_names))
+math_symbols_pattern = re.compile(
+    '|'.join(['_',  r'\^', r'\\left', r'\\math', r'\\frac', r'\\sqrt']))
 
 
 class Latex(object):
@@ -24,10 +26,10 @@ class Latex(object):
         For example: V_{rms} -> V_{\mathrm{rms}}"""
 
         def foo(match):
-        
+
             word = match.group(2)
             suffix = word + match.group(3)
-        
+
             # Perhaps look up dictionary to find valid words?
             # Assume that if length 3 or more then a word.
             if word.lower() in subscripts or len(word) > 2:
@@ -42,18 +44,16 @@ class Latex(object):
         """Replace alpha with \alpha, etc."""
 
         def foo(match):
-            if match.group(1) != '\\':
-                return match.group(1) + '\\' + match.group(2)
-            return match.group(1) + match.group(2)
+            return match.group(1) + '\\' + match.group(2) + match.group(3)
+
+        return greek_letter_name_pattern.sub(foo, s)
 
-        return greek_letter_name_pattern.sub(foo, s)            
-    
     def __str__(self):
 
         s = self.str
         s = self.greek(s)
         return self.mathrm(s)
-            
+
 
 def latex_str(string):
 
@@ -77,14 +77,21 @@ def latex_format_label(s):
         return s
 
     s = latex_str(s)
-    
-    # If have _, ^, \frac, etc.  need to be in math-mode.
-    # Should prevent lcapy generating such strings and 
-    # warn user to explicity use math mode.  The tricky part is that
-    # arbitrary signals may have math symbols, say sqrt.
+
+    s2 = s
+    for macro in (r'\hspace', r'\vspace', r'\ ', r'\,', r'\;', r'\!',
+                  r'\tiny', r'\scriptsize', r'\footnotesize', r'\small',
+                  r'\normalsize', r'\large', '\Large',
+                  r'\LARGE', r'\huge', r'\Huge'):
+        s2 = s2.replace(macro, '')
+
+    # If have _, ^, \frac, etc.  need to be in math-mode.  Should
+    # prevent lcapy generating such strings and warn user to explicity
+    # use math mode.  The tricky part is that arbitrary signals may
+    # have math symbols, say sqrt.
     math_symbols = ('_',  '^', '\\')
     for math_symbol in math_symbols:
-        if math_symbol in s:
+        if math_symbol in s2:
             return '$' + s + '$'
     return s
 
@@ -101,5 +108,3 @@ def latex_format_node_label(s):
         return '%s$_{\mathrm{%s}}$' % (parts[0], parts[1])
 
     return s
-
-    
