@@ -18,6 +18,7 @@ from .units import u as uu
 from .utils import factor_const
 from sympy import Integral, Expr as symExpr
 
+
 class NormFourierDomainExpression(NormFourierDomain, Expr):
 
     """Normalized  Fourier domain expression or symbol."""
@@ -46,7 +47,8 @@ class NormFourierDomainExpression(NormFourierDomain, Expr):
         """Attempt inverse Fourier transform."""
 
         expr = self.subs(2 * pi * fsym * dt)
-        result = inverse_fourier_transform(expr.sympy, fsym, tsym, evaluate=evaluate)
+        result = inverse_fourier_transform(
+            expr.sympy, fsym, tsym, evaluate=evaluate)
 
         return self.change(result, 'time', units_scale=uu.Hz, **assumptions)
 
@@ -147,18 +149,21 @@ class NormFourierDomainExpression(NormFourierDomain, Expr):
         return plot_frequency(self, Fvector, plot_type=plot_type,
                               norm=True, **kwargs)
 
-    def bode_plot(self, fvector=None, **kwargs):
+    def bode_plot(self, fvector=None, unwrap=True, **kwargs):
         """Plot frequency response for a frequency-domain phasor as a Bode
         plot (but without the straight line approximations).  fvector
-        specifies the normalised frequencies.  If it is a tuple (f1, f2), it sets
-        the frequency limits.   Since a logarithmic frequency scale is used,
-        f1 must be greater than 0.
+        specifies the normalised frequencies.  If it is a tuple (f1,
+        f2), it sets the frequency limits.  Since a logarithmic
+        frequency scale is used, f1 must be greater than 0.
+
+        `unwrap` controls phase unwrapping (default True).
 
         For more info, see `plot`.
+
         """
 
         from .plot import plot_bode
-        return plot_bode(self, fvector, norm=True, **kwargs)
+        return plot_bode(self, fvector, norm=True, unwrap=unwrap, **kwargs)
 
     def nyquist_plot(self, fvector=None, log_frequency=False, **kwargs):
         """Plot frequency response as a Nyquist plot (imaginary part versus
@@ -202,7 +207,8 @@ def Fexpr(arg, **assumptions):
         return F
     return expr_make('norm fourier', arg, **assumptions)
 
-from .expressionclasses import expressionclasses
+
+from .expressionclasses import expressionclasses  # nopep8
 
 classes = expressionclasses.register('norm fourier',
                                      NormFourierDomainExpression)
