@@ -15,6 +15,7 @@ from sympy import Expr as symExpr
 
 __all__ = ('omegaexpr', )
 
+
 class AngularFourierDomainExpression(AngularFourierDomain, Expr):
     """Fourier domain expression or symbol (angular frequency)."""
 
@@ -22,7 +23,8 @@ class AngularFourierDomainExpression(AngularFourierDomain, Expr):
 
     def __init__(self, val, **assumptions):
 
-        super(AngularFourierDomainExpression, self).__init__(val, **assumptions)
+        super(AngularFourierDomainExpression,
+              self).__init__(val, **assumptions)
 
         if self.expr.has(ssym):
             raise ValueError(
@@ -118,27 +120,31 @@ class AngularFourierDomainExpression(AngularFourierDomain, Expr):
         from .plot import plot_angular_frequency
         return plot_angular_frequency(self, wvector, **kwargs)
 
-    def bode_plot(self, wvector=None, **kwargs):
+    def bode_plot(self, wvector=None, unwrap=True, **kwargs):
         """Plot frequency response for a frequency-domain phasor as a Bode
         plot (but without the straight line approximations).  wvector
         specifies the angular frequencies.  If it is a tuple (f1, f2), it sets
         the frequency limits.   Since a logarithmic frequency scale is used,
         f1 must be greater than 0.
 
+        `unwrap` controls phase unwrapping (default True).
+
         For more info, see `plot`.
         """
 
         from .plot import plot_angular_bode
-        return plot_angular_bode(self, wvector, **kwargs)
+        return plot_angular_bode(self, wvector, unwrap=unwrap, **kwargs)
 
     def nyquist_plot(self, wvector=None, log_frequency=True, **kwargs):
         """Plot frequency response as a Nyquist plot (imaginary part versus
-        real part).  wvector specifies the angular frequencies.  If it is
-        a tuple (f1, f2), it sets the frequency limits as (f1, f2).
+        real part).  wvector specifies the angular frequencies.  If it
+        is a tuple (f1, f2), it sets the frequency limits as (f1, f2).
 
         `npoints` set the number of plotted points.
 
-        The unit circle is shown by default.  This can be disabled with `unitcircle=False`.
+        The unit circle is shown by default.  This can be disabled
+        with `unitcircle=False`.
+
         """
 
         from .plot import plot_nyquist
@@ -162,18 +168,13 @@ def omegaexpr(arg, **assumptions):
 
     if arg is omegasym:
         return omega
-    if arg is omega0sym:
-        return omega0
     return expr_make('angular fourier', arg, **assumptions)
 
 
-from .expressionclasses import expressionclasses
+from .expressionclasses import expressionclasses  # nopep8
 
-classes = expressionclasses.register('angular fourier', AngularFourierDomainExpression)
+classes = expressionclasses.register('angular fourier',
+                                     AngularFourierDomainExpression)
 
 omega = AngularFourierDomainExpression('omega')
 omega.units = uu.rad / uu.s
-
-# This represents a specific angular frequency and is assumed to be positive
-omega0 = AngularFourierDomainExpression('omega_0', positive=True)
-omega0.units = uu.rad / uu.s
