@@ -19,7 +19,7 @@ Copyright 2014--2022 Michael Hayes, UCECE
 """
 
 from __future__ import division
-from .functions import Heaviside, cos, exp
+from .functions import Heaviside, cos, exp, Derivative, Integral
 from .sym import omega0sym, tsym, ksym, oo
 from .symbols import j, t, s
 from .network import Network
@@ -28,7 +28,6 @@ from .impedance import impedance
 from .admittance import admittance
 from .voltage import voltage
 from .current import current
-from sympy import Derivative, Integral
 from warnings import warn
 
 
@@ -329,13 +328,17 @@ class OnePort(Network, ImmittanceMixin):
             return self + Vn
         return self
 
-        def i_equation(self, v, kind='t'):
+        def current_equation(self, v, kind='t'):
+            """Return expression for current through component given
+            applied voltage."""
 
-            raise NotImplementedError('i_equation not defined')
+            raise NotImplementedError('current_equation not defined')
 
-        def v_equation(self, i, kind='t'):
+        def voltage_equation(self, i, kind='t'):
+            """Return expression for voltage across component given
+            applied current."""
 
-            raise NotImplementedError('v_equation not defined')
+            raise NotImplementedError('voltage_equation not defined')
 
     def _Zkind(self, kind):
 
@@ -831,11 +834,15 @@ class R(OnePort):
         self._R = cexpr(Rval)
         self._Z = impedance(self._R, causal=True)
 
-    def i_equation(self, v, kind='t'):
+    def current_equation(self, v, kind='t'):
+        """Return expression for current through component given
+        applied voltage."""
 
         return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self._Z).select(kind)
 
-    def v_equation(self, i, kind='t'):
+    def voltage_equation(self, i, kind='t'):
+        """Return expression for voltage across component given
+        applied current."""
 
         return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Z).select(kind)
 
@@ -868,11 +875,15 @@ class G(OnePort):
         opts_str = self._opts_str(dir)
         return 'R? %s %s {%s}; %s' % (n1, n2, 1 / self._G, opts_str)
 
-    def i_equation(self, v, kind='t'):
+    def current_equation(self, v, kind='t'):
+        """Return expression for current through component given
+        applied voltage."""
 
         return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self._Z).select(kind)
 
-    def v_equation(self, i, kind='t'):
+    def voltage_equation(self, i, kind='t'):
+        """Return expression for voltage across component given
+        applied current."""
 
         return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Z).select(kind)
 
@@ -910,20 +921,31 @@ class L(OnePort):
         self._Voc = SuperpositionVoltage(LaplaceDomainExpression(-i0 * Lval))
         self.zeroic = self.i0 == 0
 
-    def i_equation(self, v, kind='t'):
+    def current_equation(self, v, kind='t'):
+        """Return expression for current through component given
+        applied voltage."""
 
         from .sym import tausym
 
         if kind in ('t', 'time', 'super'):
             u = tausym
             v = expr(v).subs(t, u)
-            return SuperpositionCurrent(expr(Integral(v.expr, (u, -oo, tsym))) / self.L).select(kind)
+            if self.has_ic:
+                return SuperpositionCurrent(Integral(v, (u, 0, tsym)) / self.L).select(kind) + expr(self.i0)
+
+            return SuperpositionCurrent(Integral(v, (u, -oo, tsym)) / self.L).select(kind)
+        elif kind in ('s', 'laplace'):
+            return SuperpositionCurrent((SuperpositionVoltage(v).select(kind) + self.L * self.i0) / self._Zkind(kind)).select(kind)
         return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self._Zkind(kind)).select(kind)
 
-    def v_equation(self, i, kind='t'):
+    def voltage_equation(self, i, kind='t'):
+        """Return expression for voltage across component given
+        applied current."""
 
         if kind in ('t', 'time', 'super'):
-            return SuperpositionVoltage(self.L * expr(Derivative(i.expr, t))).select(kind)
+            return SuperpositionVoltage(self.L * Derivative(i, t)).select(kind)
+        elif kind in ('s', 'laplace'):
+            return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Zkind(kind) - self.L * self.i0).select(kind)
         return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Zkind(kind)).select(kind)
 
 
@@ -954,20 +976,33 @@ class C(OnePort):
         self._Voc = SuperpositionVoltage(LaplaceDomainExpression(v0 / s))
         self.zeroic = self.v0 == 0
 
-    def i_equation(self, v, kind='t'):
+    def current_equation(self, v, kind='t'):
+        """Return expression for current through component given
+        applied voltage."""
 
         if kind in ('t', 'time', 'super'):
-            return SuperpositionCurrent(self.C * expr(Derivative(v.expr, t))).select(kind)
+            return SuperpositionCurrent(self.C * Derivative(v, t)).select(kind)
+        elif kind in ('s', 'laplace'):
+            return SuperpositionCurrent((SuperpositionVoltage(v).select(kind) - self.v0 / s) / self._Zkind(kind)).select(kind)
+
         return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self._Zkind(kind)).select(kind)
 
-    def v_equation(self, i, kind='t'):
+    def voltage_equation(self, i, kind='t'):
+        """Return expression for voltage across component given
+        applied current."""
 
         from .sym import tausym
 
         if kind in ('t', 'time', 'super'):
             u = tausym
             i = expr(i).subs(t, u)
-            return SuperpositionVoltage(expr(Integral(i.expr, (u, -oo, tsym))) / self.C).select(kind)
+            if self.has_ic:
+                return SuperpositionVoltage(Integral(i, (u, 0, tsym)) / self.C).select(kind) + expr(self.v0)
+
+            return SuperpositionVoltage(Integral(i, (u, -oo, tsym)) / self.C).select(kind)
+        elif kind in ('s', 'laplace'):
+            return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Zkind(kind) + self.v0 / s).select(kind)
+
         return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Zkind(kind)).select(kind)
 
 
@@ -1026,7 +1061,9 @@ class VoltageSourceBase(OnePort):
     cpt_type = 'V'
     is_noisy = False
 
-    def v_equation(self, i, kind='t'):
+    def voltage_equation(self, i, kind='t'):
+        """Return expression for voltage across component given
+        applied current."""
 
         return SuperpositionVoltage(self.voc).select(kind)
 
@@ -1161,11 +1198,12 @@ class CurrentSourceBase(OnePort):
 
     @property
     def I(self):
-        """Open-circuit current of a current source.  To achieve this the
-        open-circuit voltage needs to be infinite."""
+        """Open-circuit current of a current source."""
         return self.Isc
 
-    def i_equation(self, v, kind='t'):
+    def current_equation(self, v, kind='t'):
+        """Return expression for current through component given
+        applied voltage."""
 
         return SuperpositionCurrent(self.isc).select(kind)
 
