@@ -2,14 +2,15 @@
 Current and Voltage.  It represents voltages and currents as a
 superposition in different transform domains.
 
-Copyright 2019--2021 Michael Hayes, UCECE
+Copyright 2019--2022 Michael Hayes, UCECE
 
 """
 
 from __future__ import division
+import sys
 import sympy as sym
 from .expr import Expr, ExprDict, expr
-from .sym import tsym, omega0sym, symbols_find, is_sympy, symsymbol
+from .sym import tsym, omega0sym, symbols_find, is_sympy
 from .acdc import is_ac
 from .state import state
 from .domains import SuperpositionDomain
@@ -59,7 +60,7 @@ class Superposition(SuperpositionDomain, ExprDict):
     # The 's' key is the transient component viewed in the Laplace domain.
 
     def __init__(self, *args, **kwargs):
-        super (Superposition, self).__init__()
+        super(Superposition, self).__init__()
 
         for arg in args:
 
@@ -137,6 +138,8 @@ class Superposition(SuperpositionDomain, ExprDict):
     def decompose_to_domain(self, expr, kind):
 
         cls = domain_kind_quantity_to_class(kind, self.quantity)
+        if cls.is_phasor_domain:
+            return cls(expr, omega=kind)
         return cls(expr)
 
     @property
@@ -155,7 +158,8 @@ class Superposition(SuperpositionDomain, ExprDict):
         necessary to transform to a specific domain.  For example,
         using `V(s)`."""
 
-        raise AttributeError("""Units are not defined for a superposition; convert to a specific domain, say using `V(t)` or `V(s)`.""")
+        raise AttributeError(
+            """Units are not defined for a superposition; convert to a specific domain, say using `V(t)` or `V(s)`.""")
 
     def ac_keys(self):
         """Return list of keys for all ac components."""
@@ -192,7 +196,7 @@ class Superposition(SuperpositionDomain, ExprDict):
         V.has_symbol(t)
 
         """
-        return self.has(symsymbol(sym))
+        return self.has(expr(sym))
 
     @property
     def has_dc(self):
@@ -335,7 +339,8 @@ class Superposition(SuperpositionDomain, ExprDict):
             x = x.as_quantity(self.quantity)
 
         if x.quantity != self.quantity:
-            raise ValueError('Incompatible quantities %s and %s' % (self.quantity, x.quantity))
+            raise ValueError('Incompatible quantities %s and %s' %
+                             (self.quantity, x.quantity))
 
         if _is_s_arg(x):
             new = self.decompose()
@@ -506,7 +511,7 @@ class Superposition(SuperpositionDomain, ExprDict):
 
         val = self.select(kind)
         if (isinstance(kind, str) and kind in ('s', 'ivp') and
-            (val.is_causal or val.is_dc or val.is_ac)):
+                (val.is_causal or val.is_dc or val.is_ac)):
             # Convert to time representation so that can re-infer
             # causality, etc.
             return val.time()
@@ -521,6 +526,13 @@ class Superposition(SuperpositionDomain, ExprDict):
 
         return keyword, val
 
+    def _netrepr(self):
+        """Format value as a string value for a netlist."""
+
+        # FIXME: converting to time-domain is only required
+        # if have a superposition of values.
+        return str(self.time())
+
     def _kind(self, value):
         if isinstance(value, PhasorTimeDomainExpression):
             # Use angular frequency for key.  This can be a nuisance
@@ -583,8 +595,8 @@ class Superposition(SuperpositionDomain, ExprDict):
             delattr(self, '_decomposition')
 
         if isinstance(value, Superposition):
-            for kind, value in value.items():
-                self.add(value)
+            for kind, value1 in value.items():
+                self.add(value1)
             return
 
         if isinstance(value, str):
@@ -620,7 +632,7 @@ class Superposition(SuperpositionDomain, ExprDict):
     def magnitude(self):
         """Return the magnitude if phasor."""
 
-        phasor = self.phasor
+        phasor = self.phasor()
         return phasor.magnitude
 
     @property
@@ -637,7 +649,7 @@ class Superposition(SuperpositionDomain, ExprDict):
     def phase(self):
         """Return the phase if phasor."""
 
-        phasor = self.phasor
+        phasor = self.phasor()
         return phasor.phase
 
     @property
@@ -753,7 +765,8 @@ expression.""")
         """Convert to angular Fourier domain."""
 
         # TODO, could optimise.
-        return self.time(**assumptions).angular_fourier(**assumptions)
+        tresult = self.time(**assumptions)
+        return tresult.angular_fourier(**assumptions)
 
     def canonical(self):
         new = self.__class__()
@@ -788,19 +801,19 @@ expression.""")
             return self.time()
         return self
 
-from .cexpr import ConstantDomainExpression
-from .fexpr import FourierDomainExpression
-from .sexpr import LaplaceDomainExpression
-from .texpr import TimeDomainExpression
-from .noiseexpr import NoiseExpression
-from .phasor import PhasorTimeDomainExpression
-from .omegaexpr import AngularFourierDomainExpression
-from .symbols import s, omega
+
+from .cexpr import ConstantDomainExpression  # nopep8
+from .fexpr import FourierDomainExpression  # nopep8
+from .sexpr import LaplaceDomainExpression  # nopep8
+from .texpr import TimeDomainExpression  # nopep8
+from .noiseexpr import NoiseExpression  # nopep8
+from .phasor import PhasorTimeDomainExpression  # nopep8
+from .omegaexpr import AngularFourierDomainExpression  # nopep8
+from .symbols import s, omega  # nopep8
 
 
 # See expr.py
 
-import sys
 try:
     from .printing import latex
     formatter = sys.displayhook.shell.display_formatter.formatters['text/latex']
