@@ -45,26 +45,26 @@ class SuperpositionVoltage(Superposition, VoltageMixin):
 
         if isinstance(x, Superposition):
             raise TypeError('Cannot multiply %s by %s. '
-            'You need to extract a specific component, e.g., a.s * b.s' %
-            (type(self).__name__, type(x).__name__))
+                            'You need to extract a specific component, e.g., a.s * b.s' %
+                            (type(self).__name__, type(x).__name__))
 
         if not x.is_admittance:
             raise TypeError("Unsupported types for *: 'Voltage' and '%s'" %
                             type(x).__name__)
         if x.is_time_domain:
             raise TypeError("Cannot multiply by time-domain impedance.")
-        
+
         obj = self
         if 't' in self and not x.is_constant_domain:
             obj = self.decompose()
         xs = x.laplace()
-            
+
         new = SuperpositionCurrent()
         if 'dc' in obj:
             new += obj['dc'] * xs(0)
         for key in obj.ac_keys():
             new += obj[key] * xs(j * obj[key].omega)
-        for key in obj.noise_keys():            
+        for key in obj.noise_keys():
             new += obj[key] * xs(omega)
         if 's' in obj:
             new += obj['s'] * xs
@@ -82,24 +82,26 @@ class SuperpositionVoltage(Superposition, VoltageMixin):
 
         if not x.is_impedance:
             raise TypeError("Cannot divide '%s' by '%s'; require impedance" %
-                            (type(self).__name__, type(x).__name__))        
+                            (type(self).__name__, type(x).__name__))
 
         Y = 1 / x
         return self * Y
 
     def __mul__(self, x):
         if False:
-            raise ValueError('Cannot multiply superposition, need to convert to specific domain')        
+            raise ValueError(
+                'Cannot multiply superposition, need to convert to specific domain')
         return self._mul(x)
-    
+
     def __rmul__(self, x):
         return self._mul(x)
 
     def __truediv__(self, x):
         if False:
-            raise ValueError('Cannot divide superposition, need to convert to specific domain')        
-        
-        return self._div(x)    
+            raise ValueError(
+                'Cannot divide superposition, need to convert to specific domain')
+
+        return self._div(x)
 
 
-from .superpositioncurrent import SuperpositionCurrent
+from .superpositioncurrent import SuperpositionCurrent  # nopep8
