@@ -305,3 +305,33 @@ class LcapyOneportTester(unittest.TestCase):
         self.assertEqual(type(admittance(2).cpt()), G, "-> G")
         self.assertEqual(type(admittance(2 * s).cpt()), C, "-> C")
         self.assertEqual(type(admittance(2 / s).cpt()), L, "-> L")
+
+    def test_C_equation(self):
+
+        a = C('C', 'v0')
+
+        self.assertEqual(a.voltage_equation('I(s)', 's'),
+                         voltage('I(s) / (s * C) + v0 / s'),
+                         "C voltage_equation in s-domain")
+        self.assertEqual(a.current_equation('V(s)', 's'),
+                         current('s * C * (V(s) - v0 / s)'),
+                         "C current_equation in s-domain")
+
+        self.assertEqual(a.voltage_equation('I(s)', 's'),
+                         a.voltage_equation('i(t)', 't')(s),
+                         "C current_equation in t-domain")
+
+    def test_L_equation(self):
+
+        a = L('L', 'i0')
+
+        self.assertEqual(a.voltage_equation('I(s)', 's'),
+                         voltage('s * L * I(s) - L * i0'),
+                         "L voltage_equation in s-domain")
+        self.assertEqual(a.current_equation('V(s)', 's'),
+                         current('(V(s) + L * i0) / (s * L)'),
+                         "L current_equation in s-domain")
+
+        self.assertEqual(a.current_equation('V(s)', 's'),
+                         a.current_equation('v(t)', 't')(s),
+                         "L current_equation in t-domain")
