@@ -9,11 +9,12 @@ from __future__ import division
 from .domains import TimeDomain
 from .expr import Expr, expr_make
 from .functions import exp
+from .state import state
 from .sym import fsym, ssym, tsym, j, oo
 from .laplace import laplace_transform
 from .fourier import fourier_transform
 from .units import u as uu
-from sympy import Heaviside, Integral, limit, Expr as symExpr
+from sympy import Heaviside, Derivative, Integral, limit, Expr as symExpr
 
 
 __all__ = ('texpr', )
@@ -31,7 +32,8 @@ class TimeDomainExpression(TimeDomain, Expr):
         super(TimeDomainExpression, self).__init__(val, **assumptions)
 
         expr = self.expr
-        if check and expr.has(ssym) and not expr.has(Integral):
+        # Should be more specific...
+        if check and expr.has(ssym) and not expr.has(Integral) and not expr.has(Derivative):
             raise ValueError(
                 't-domain expression %s cannot depend on s' % expr)
         if check and expr.has(fsym) and not expr.has(Integral):
@@ -65,21 +67,36 @@ class TimeDomainExpression(TimeDomain, Expr):
 
         self.assumptions.infer_from_expr(self)
 
-    def LT(self, evaluate=True, **assumptions):
+    def LT(self, evaluate=True, zero_initial_conditions=None, **assumptions):
         """Determine one-sided Laplace transform with 0- as the lower limit.
 
-        This is an alias for laplace."""
+        By default initial conditions are assumed to be zero.  This
+        can be controlled by `zero_initial_conditions`.
 
-        return self.laplace(evaluate, **assumptions)
+        This is an alias for laplace.
 
-    def laplace(self, evaluate=True, **assumptions):
-        """Determine one-sided Laplace transform with 0- as the lower limit."""
+        """
+        if zero_initial_conditions is None:
+            zero_initial_conditions = state.zero_initial_conditions
 
         assumptions = self.assumptions.merge_and_infer(self, **assumptions)
         result = laplace_transform(
-            self.expr, self.var, ssym, evaluate=evaluate)
+            self.expr, self.var, ssym, evaluate=evaluate,
+            zero_initial_conditions=zero_initial_conditions)
         return self.change(result, domain='laplace', units_scale=uu.s, **assumptions)
 
+    def laplace(self, evaluate=True, zero_initial_conditions=None,
+                **assumptions):
+        """Determine one-sided Laplace transform with 0- as the lower limit.
+
+        By default initial conditions are assumed to be zero.  This
+        can be controlled by `zero_initial_conditions`.
+
+        This is an alias for LT."""
+
+        return self.LT(evaluate=evaluate, zero_initial_conditions=zero_initial_conditions,
+                       **assumptions)
+
     def phasor(self, **assumptions):
         """Convert to phasor domain."""
 
@@ -90,7 +107,7 @@ class TimeDomainExpression(TimeDomain, Expr):
     def FT(self, var=None, evaluate=True, **assumptions):
         """Attempt Fourier transform.
 
-        X(f) = \int_{-\infty}^{\infty} x(t) exp(-j 2\pi f t) dt."""
+        X(f) = \int_{-\infty} ^ {\infty} x(t) exp(-j 2\pi f t) dt."""
 
         from .symbols import f, omega, Omega, F
 
@@ -145,7 +162,7 @@ class TimeDomainExpression(TimeDomain, Expr):
 
     def plot(self, t=None, **kwargs):
         """Plot the time waveform.  If t is not specified, it defaults to the
-        range (-0.2, 2).  t can be a vector of specified instants, a
+        range(-0.2, 2).  t can be a vector of specified instants, a
         tuple specifing the range, or a constant specifying the
         maximum value with the minimum value set to 0.
 
@@ -215,18 +232,18 @@ class TimeDomainExpression(TimeDomain, Expr):
     def discretize(self, method='bilinear', alpha=0.5):
         """Convert to a discrete-time approximation:
 
-        :math:`h[n] \approx h(t)`
+        : math: `h[n] \approx h(t)`
 
         With the impulse-invariance method, the discrete-time impulse response
         is related to the continuous-time impulse response by
 
-        :math:`h[n] = h_c(n \Delta t)`
+        : math: `h[n] = h_c(n \Delta t)`
 
         Note, when designing digital filters, it is often common to to
         scale the discrete-time impulse response by the sampling
         interval:
 
-        :math:`h[n] = \Delta t h_c(n \Delta t)`
+        : math: `h[n] = \Delta t h_c(n \Delta t)`
 
         The default method is 'bilinear'.  Other methods are:
         'impulse-invariance' 'bilinear', 'tustin', 'trapezoidal'
